/*
	Filename         : cis_header.js
	Last modified by : jmueller
	Created          : 04/27/1999 10:21:06
	Last Updated     : 11/22/1999 13:47:25
	Comments         : 
	
	This script will insert commented header information into the top of
	current file with the filename, username, and dates already filled in.
	The header will be commented out in a manner appropriate to the
	file type being edited.
	
	Subsequent calls to this script will update the "Last Updated" field
	and the "Last modified by" field, without modifying anything else.
	
	Script requires HomeSite/Studio 4.01, Windows Scripting Host.
	
	Currently supported: 
	cfm, asp, asa, js, vbs, htm, bas, css, html, shtml, stm, pl, php3
	
	Joel Mueller
	joel@teamallaire.com
*/

function Main() {
	var app = Application;
	var active = app.ActiveDocument;
	var insertString = new String();
	var curDate = new Date();
	var WSHNetwork = new ActiveXObject("WScript.Network");
	var curFile = active.Filename;
	var curExt = new String();
	var created = new Date();
	if (curFile.length > 0) {
		curExt = curFile.substring(curFile.lastIndexOf(".") + 1, curFile.length).toLowerCase();
		// get the current file's last-modified date
		var protocol = curFile.substring(0,6).toLowerCase();
		if (protocol != "ftp://" && protocol != "rds://") {
			// can only get the creation date on local files
			var objFileSys = new ActiveXObject("Scripting.FileSystemObject");
			var objFile = objFileSys.GetFile(curFile);
			created = new Date(Date.parse(objFile.DateCreated));
			objFile = null;
			objFileSys = null;
		}
	}
	
	var headerBegin = new String();
	var headerEnd = new String();
	var lineBegin = new String();
	
	switch (curExt) {
		case "cfm":
			headerBegin = "<!---\n";
			headerEnd = "--->\n";
			lineBegin = "	";
			break;
		case "asp":
			headerBegin = "<%\n";
			headerEnd = "%>\n";
			lineBegin = "'	";
			break;
		case "asa":
			headerBegin = "<%\n";
			headerEnd = "%>\n";
			lineBegin = "'	";
			break;
		case "vbs":
			headerBegin = "'	*******\n";
			headerEnd = "'	*******\n";
			lineBegin = "'	";
			break;
		case "bas":
			headerBegin = "'	*******\n";
			headerEnd = "'	*******\n";
			lineBegin = "'	";
			break;
		case "js":
			headerBegin = "/*\n";
			headerEnd = "*/\n";
			lineBegin = "	";
			break;
		case "css":
			headerBegin = "/*\n";
			headerEnd = "*/\n";
			lineBegin = "	";
			break;
		case "htm":
			headerBegin = "<!--\n";
			headerEnd = "-->\n";
			lineBegin = "	";
			break;
		case "html":
			headerBegin = "<!--\n";
			headerEnd = "-->\n";
			lineBegin = "	";
			break;
		case "shtml":
			headerBegin = "<!--\n";
			headerEnd = "-->\n";
			lineBegin = "	";
			break;
		case "stm":
			headerBegin = "<!--\n";
			headerEnd = "-->\n";
			lineBegin = "	";
			break;
		case "php3":
			headerBegin = "/*\n";
			headerEnd = "*/\n";
			lineBegin = "	";
			break;
		case "pl":
			headerBegin = "#	*******\n";
			headerEnd = "#	*******\n";
			lineBegin = "#	";
			break;
		default:
			headerBegin = "<!---\n";
			headerEnd = "--->\n";
			lineBegin = "	";
			break;
	}
	
	// Insert header after ASP <%@ %> command
	// or CFSETTING on first line.
	var LineNum = 0;
	var topLine = active.Lines(LineNum);
	var ASPLine = /<% ?@/;
	var CFLine = /(<CFSETTING *EnableCFOutputOnly)|(<CFSILENT[^>]*>)/i;
	if (ASPLine.test(topLine) || CFLine.test(topLine)) {
		LineNum = 1;
		if (curExt == "asp") {
			// Check for ASP LANGUAGE setting to configure comment marks appropriately.
			var ASPLang = /LANGUAGE ?= ?"?(vbscript|javascript|jscript|perlscript)/i;
			if (ASPLang.test(topLine)) {
				switch (RegExp.$1.toLowerCase()) {
					case "vbscript":
						headerBegin = "<%\n";
						headerEnd = "%>\n";
						lineBegin = "'	";
						break;
					case "javascript":
						headerBegin = "<%\n";
						headerEnd = "%>\n";
						lineBegin = "//	";
						break;
					case "jscript":
						headerBegin = "<%\n";
						headerEnd = "%>\n";
						lineBegin = "//	";
						break;
					case "perlscript":
						headerBegin = "<%\n";
						headerEnd = "%>\n";
						lineBegin = "#	";
						break;
				}
			}
		}
	}
	
	// Does the header already exist in this file?
	var RElineBegin = REFormat(lineBegin);
	var REHeader = eval("/" + RElineBegin + "Filename         : ([^\\n]*)\\n" + RElineBegin + "Last modified by : ([^\\n]*)\\n" + RElineBegin + "Created          : ([^\\n]*)\\n" + RElineBegin + "Last Updated     : ([^\\n]*)\\n/");
	
	// Remember cursor position.
	// Use ScriptX to invoke by reference (built into HS 4.01)
	var objScriptX = new ActiveXObject("ScriptX.Factory");
	var args = new Array(0,0);
	objScriptX.js.InvokeByRef(active, "GetCaretPos", args);	

	if (REHeader.test(active.Text)) {
		insertString += lineBegin + "Filename         : " + app.ExtractFileName(curFile) + "\n";
		insertString += lineBegin + "Last modified by : " + WSHNetwork.UserName + "\n";
		insertString += lineBegin + "Created          : " + RegExp.$3 + "\n";
		insertString += lineBegin + "Last Updated     : " + curDate.toLocaleString() + "\n";
		
		active.Text = active.Text.replace(REHeader, insertString);
		
		// restore the cursor position
		active.SetCaretPos(args[0], args[1]);
	} else {	
		insertString += headerBegin;
		insertString += lineBegin + "Filename         : " + app.ExtractFileName(curFile) + "\n";
		insertString += lineBegin + "Last modified by : " + WSHNetwork.UserName + "\n";
		insertString += lineBegin + "Created          : " + created.toLocaleString() + "\n";
		insertString += lineBegin + "Last Updated     : " + curDate.toLocaleString() + "\n";
		insertString += lineBegin + "Comments         : \n";
		insertString += headerEnd + "\n";
	
		active.Lines(LineNum) = insertString + active.Lines(LineNum);
		
		// restore the cursor position, plus 8 lines for the header
		active.SetCaretPos(args[0], args[1] + 8);
	}

	app.StatusWarning("Header Inserted");

	WSHNetwork = null;
	objScriptX = null;
}

function REFormat(string) {
	var badChars = /([\/\\\*\[\]\?\.\(\)\+])/g;
	return string.replace(badChars, "\\\$1");
}

